← Back to team overview

dhis2-devs team mailing list archive

[Branch ~dhis2-devs-core/dhis2/trunk] Rev 14253: rename from programPersonAttribute to programTrackedEntityAttribute on Program

 

------------------------------------------------------------
revno: 14253
committer: Morten Olav Hansen <mortenoh@xxxxxxxxx>
branch nick: dhis2
timestamp: Mon 2014-03-17 14:41:15 +0100
message:
  rename from programPersonAttribute to programTrackedEntityAttribute on Program
modified:
  dhis-2/dhis-api/src/main/java/org/hisp/dhis/program/Program.java


--
lp:dhis2
https://code.launchpad.net/~dhis2-devs-core/dhis2/trunk

Your team DHIS 2 developers is subscribed to branch lp:dhis2.
To unsubscribe from this branch go to https://code.launchpad.net/~dhis2-devs-core/dhis2/trunk/+edit-subscription
=== modified file 'dhis-2/dhis-api/src/main/java/org/hisp/dhis/program/Program.java'
--- dhis-2/dhis-api/src/main/java/org/hisp/dhis/program/Program.java	2014-03-17 08:37:35 +0000
+++ dhis-2/dhis-api/src/main/java/org/hisp/dhis/program/Program.java	2014-03-17 13:41:15 +0000
@@ -121,7 +121,7 @@
     private Set<OrganisationUnitGroup> organisationUnitGroups = new HashSet<OrganisationUnitGroup>();
 
     /**
      * Allow enrolling person to all orgunit no matter what the program is
      * assigned for the orgunit or not
      */
     private Boolean displayOnAllOrgunit = true;
@@ -555,10 +555,10 @@
         this.dataEntryMethod = dataEntryMethod;
     }
 
-    @JsonProperty( value = "programPersonAttributes" )
+    @JsonProperty( value = "programTrackedEntityAttributes" )
     @JsonView( { DetailedView.class, ExportView.class, WithoutOrganisationUnitsView.class } )
-    @JacksonXmlElementWrapper( localName = "programPersonAttributes", namespace = DxfNamespaces.DXF_2_0 )
-    @JacksonXmlProperty( localName = "programPersonAttribute", namespace = DxfNamespaces.DXF_2_0 )
+    @JacksonXmlElementWrapper( localName = "programTrackedEntityAttributes", namespace = DxfNamespaces.DXF_2_0 )
+    @JacksonXmlProperty( localName = "programTrackedEntityAttribute", namespace = DxfNamespaces.DXF_2_0 )
     public Set<ProgramTrackedEntityAttribute> getAttributes()
     {
         return attributes;
@@ -121,7 +121,7 @@
 
     /**
-     * Allow enrolling person to all orgunit no matter what the program is
+     * Allow enrolling trackedEntity to all orgunit no matter what the program is
      * assigned for the orgunit or not
      */